@@ -14,6 +14,7 @@
 
 #include "config.h"
 
+#include <cgraph/cgraph.h>
 #include <gvc/gvc.h>
 #include <gvc/gvio.h>
 
@@ -37,6 +38,8 @@ static graph_t * G;
 #ifndef _WIN32
 static void intr(int s)
 {
+    (void)s;
+
 /* if interrupted we try to produce a partial rendering before exiting */
     if (G)
 	gvRenderJobs(Gvc, G);
