@@ -8,14 +8,10 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#ifdef __cplusplus
-extern "C" {
-#endif
-
 /* Lefteris Koutsofios - AT&T Labs Research */
 
-#ifndef _TBL_H
-#define _TBL_H
+#pragma once
+
 #ifdef _WIN32
 #include "mem.h"
 #endif
@@ -132,8 +128,3 @@ void Tdelo (Tobj, Tobj);
 Tobj Tcopy (Tobj);
 void Tgetfirst (Tobj, Tkvindex_t *);
 void Tgetnext (Tkvindex_t *);
-#endif /* _TBL_H */
-
-#ifdef __cplusplus
-}
-#endif
