@@ -18,108 +18,11 @@
 #include <common/memory.h>
 #include <cgraph/strcasecmp.h>
 
-
-static char guibuffer[BUFSIZ];	//general purpose buffer
-
-GdkWindow *window1;
-GtkWidget *statusbar1;
-
 GladeXML *xml;			//global libglade vars
 GtkWidget *gladewidget;
 
-//1 subgraph 2 node 3 edge
-int frmObjectTypeIndex;
-Agraph_t *frmObjectg;
-
-
-GtkComboBox *cbSelectGraph;	//combo at top left
-
-GtkWidget *AttrWidgets[MAXIMUM_WIDGET_COUNT];
-GtkWidget *AttrLabels[MAXIMUM_WIDGET_COUNT];
-int attr_widgets_modified[MAXIMUM_WIDGET_COUNT];
-int widgetcounter;		//number of attributes counted dynamically, might be removed in the future 
 attribute attr[MAXIMUM_WIDGET_COUNT];
 
-
-
-//loads object properties form and does some fixes
-//call this function only ones
-void create_object_properties(void)
-{
-    GladeXML *xml;
-    GtkWidget *widget;
-    xml = glade_xml_new(smyrnaGlade, NULL, NULL);
-
-    widget = glade_xml_get_widget(xml, "listPoints");
-    gtk_clist_set_column_title((GtkCList *) widget, 0, "Def");
-    gtk_clist_set_column_title((GtkCList *) widget, 1, "x");
-    gtk_clist_set_column_title((GtkCList *) widget, 2, "y");
-    gtk_clist_set_column_title((GtkCList *) widget, 3, "z");
-    gtk_clist_column_titles_show((GtkCList *) widget);
-    gtk_widget_show(widget);
-    widget = glade_xml_get_widget(xml, "win");
-    gtk_widget_show(widget);
-
-
-}
-
-//call this after create_object_properties()
-void object_properties_node_init(void)
-{
-
-}
-void object_properties_edge_init(void)	//customize window for Edges
-{
-}
-void object_properties_cluster_init(void)	//customize window for Cluster
-{
-
-}
-void object_properties_graph_init(void)	//customize window for Graph , this shows the graph default values
-{
-
-}
-
-
-
-GtkComboBox *get_SelectGraph(void)
-{
-    GtkComboBox *cb;
-    if (!cbSelectGraph) {
-
-	cb = (GtkComboBox *) gtk_combo_box_new_text();
-	gtk_widget_show((GtkWidget *) cb);
-	gtk_box_pack_start(GTK_BOX(gladewidget), (GtkWidget *) cb, FALSE,
-			   FALSE, 0);
-
-
-	gtk_layout_put((GtkLayout *) gladewidget, (GtkWidget *) cb, 780,
-		       3);
-	//signal
-
-
-	return cb;
-    } else
-	return cbSelectGraph;
-}
-
-void Color_Widget(char *colorstring, GtkWidget * widget)
-{
-  GtkRcStyle *rc_style;
-  GdkColor color;
-
-  gdk_color_parse (colorstring, &color);
-
-
-  rc_style = gtk_rc_style_new ();
-  /* Set foreground (fg) color in normal state to red */
-  rc_style->fg[GTK_STATE_NORMAL] = color;
-  rc_style->color_flags[GTK_STATE_NORMAL] |= GTK_RC_FG;
-
-  gtk_widget_modify_style (widget, rc_style);
-  gtk_rc_style_unref (rc_style);
-}
-
 void Color_Widget_bg(char *colorstring, GtkWidget * widget)
 {
     GdkColor color;
@@ -195,32 +98,6 @@ int update_graph_properties(Agraph_t * graph)	//updates graph from gui
     return 1;
 }
 
-
-
-char *get_attribute_string_value_from_widget(attribute * att)
-{
-    GdkColor color;
-    switch (att->Type) {
-    case 'F':
-	sprintf(guibuffer, "%f",
-		gtk_spin_button_get_value((GtkSpinButton *) att->
-					  attrWidget));
-	return guibuffer;
-	break;
-    case 'C':
-	gtk_color_button_get_color((GtkColorButton *) att->attrWidget,
-				   &color);
-	sprintf(guibuffer, "#%x%x%x", color.red / 255, color.green / 255,
-		color.blue / 255);
-	return guibuffer;
-	break;
-    default:
-	strcpy(guibuffer,
-	       gtk_entry_get_text((GtkEntry *) att->attrWidget));
-	return guibuffer;
-    }
-}
-
 void load_attributes(void)
 {
     FILE *file;
@@ -314,7 +191,7 @@ void show_gui_warning(char *str)
 						      GTK_MESSAGE_WARNING,
 						      GTK_BUTTONS_OK, "%s", str);
 
-    respond = gtk_dialog_run((GtkDialog *) Dlg);
+    gtk_dialog_run((GtkDialog *) Dlg);
     gtk_object_destroy((GtkObject *) Dlg);
 }
 
