@@ -22,18 +22,10 @@
 #include <ctype.h>
 #include  "frmobjectui.h"
 
-//file
-char buf[255];
-void mAttributesSlot(GtkWidget * widget, gpointer user_data)
-{
-    showAttrsWidget(view->Topview);
-}
-
 void mOpenSlot(GtkWidget * widget, gpointer user_data)
 {
     GtkWidget *dialog;
     GtkFileFilter *filter;
-    int i = 0;
 
     filter = gtk_file_filter_new();
     gtk_file_filter_add_pattern(filter, "*.gv");
@@ -50,15 +42,9 @@ void mOpenSlot(GtkWidget * widget, gpointer user_data)
     if (gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_ACCEPT) {
 	char *filename;
 	filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(dialog));
-/*	if (view->activeGraph == 0)
-		close_graph(view,0);*/
 
-	i = view->SignalBlock;
-	view->SignalBlock = 1;
 	add_graph_to_viewport_from_file(filename);
 	g_free(filename);
-	view->SignalBlock = i;
-
     }
 
     gtk_widget_destroy(dialog);
@@ -66,9 +52,7 @@ void mOpenSlot(GtkWidget * widget, gpointer user_data)
 
 void mSaveSlot(GtkWidget * widget, gpointer user_data)
 {
-
     save_graph();		//save without prompt
-
 }
 
 void mSaveAsSlot(GtkWidget * widget, gpointer user_data)
@@ -111,8 +95,6 @@ int show_close_nosavedlg(void)
     return rv;
 }
 
-
-
 //edit
 void mCutSlot(GtkWidget * widget, gpointer user_data)
 {
@@ -134,20 +116,13 @@ void mTopviewSettingsSlot(GtkWidget * widget, gpointer user_data)
     show_settings_form();
 }
 
-
-
 //view
 void mShowToolBoxSlot(GtkWidget * widget, gpointer user_data)
 {
-
-
     if (!gtk_widget_set_gl_capability
 	(glade_xml_get_widget(xml, "glfixed"), configure_gl(),
 	 gtk_widget_get_gl_context(view->drawing_area), 0, 0))
 	printf("glwidget creation failed \n");
-
-
-
 }
 
 void mShowConsoleSlot(GtkWidget * widget, gpointer user_data)
@@ -173,8 +148,6 @@ void mNodeListSlot(GtkWidget * widget, gpointer user_data)
 {
 	gtk_widget_show(glade_xml_get_widget(xml, "frmTVNodes"));
 	setup_tree (view->g[view->activeGraph]);
-
-
 }
 
 void mNewNodeSlot(GtkWidget * widget, gpointer user_data)
@@ -190,7 +163,6 @@ void mNewClusterSlot(GtkWidget * widget, gpointer user_data)
 
 void mGraphPropertiesSlot(GtkWidget * widget, gpointer user_data)
 {
-    int respond;
     //there has to be an active graph to open the graph prop page
     if (view->activeGraph > -1) {
 	load_graph_properties(view->g[view->activeGraph]);	//load from graph to gui              
@@ -202,9 +174,7 @@ void mGraphPropertiesSlot(GtkWidget * widget, gpointer user_data)
 					  glade_xml_get_widget(xml,
 							       "dlgOpenGraph"),
 					  2, 1);
-	respond = gtk_dialog_run((GtkDialog *)
-				 glade_xml_get_widget(xml,
-						      "dlgOpenGraph"));
+	gtk_dialog_run((GtkDialog *)glade_xml_get_widget(xml, "dlgOpenGraph"));
 	//need to hide the dialog , again freaking GTK!!!!
 	gtk_widget_hide(glade_xml_get_widget(xml, "dlgOpenGraph"));
     }
@@ -212,16 +182,13 @@ void mGraphPropertiesSlot(GtkWidget * widget, gpointer user_data)
 
 void mNodeFindSlot(GtkWidget * widget, gpointer user_data)
 {
-
 }
 
-
 static void mPropertiesSlot(gve_element element)
 {
     if (view->activeGraph >= 0)
 	gtk_widget_hide(glade_xml_get_widget(xml, "frmObject"));
     gtk_widget_show(glade_xml_get_widget(xml, "frmObject"));
-//      load_object_properties(element, view->g[view->activeGraph]);
 }
 
 void mClusterPropertiesSlot(GtkWidget * widget, gpointer user_data)
@@ -245,21 +212,6 @@ void mShowCodeSlot(GtkWidget * widget, gpointer user_data)
 static void mSlot(GtkWidget * widget, gpointer user_data,
 		  gvk_layout layout, int doCursor)
 {
-    /* GdkCursor *cursor; */
-    /* GdkWindow *w; */
-/*    Dlg = (GtkMessageDialog *) gtk_message_dialog_new(NULL,
-						      GTK_DIALOG_MODAL,
-						      GTK_MESSAGE_QUESTION,
-						      GTK_BUTTONS_YES_NO,
-						      "This will change the graph layout\n all your position changes will be lost\n Are you sure?");
-
-    respond = gtk_dialog_run((GtkDialog *) Dlg);
-    if (respond == GTK_RESPONSE_YES)
-	do_graph_layout(view->g[view->activeGraph], layout, 0);
-    gtk_object_destroy((GtkObject *) Dlg);*/
-    return;
-
-
 }
 
 void mDotSlot(GtkWidget * widget, gpointer user_data)
@@ -292,8 +244,6 @@ void mSfdpSlot(GtkWidget * widget, gpointer user_data)
     mSlot(widget, user_data, GVK_SFDP, 0);
 }
 
-
-
 void mAbout(GtkWidget * widget, gpointer user_data)
 {
 }
@@ -302,15 +252,10 @@ void mHelp(GtkWidget * widget, gpointer user_data)
 {
 }
 
-
-
 void change_cursor(GdkCursorType C)
 {
-
     GdkCursor *cursor;
-    GdkWindow *w;
     cursor = gdk_cursor_new(C);
-    w = (GdkWindow *) glade_xml_get_widget(xml, "frmMain");
     gdk_window_set_cursor((GdkWindow *) view->drawing_area->window,
 			  cursor);
     gdk_cursor_destroy(cursor);
@@ -337,7 +282,7 @@ void mTestgvpr(GtkWidget * widget, gpointer user_data)
     gtk_text_buffer_get_end_iter(gtkbuf, &endit);
     bf2 = gtk_text_buffer_get_text(gtkbuf, &startit, &endit, 0);
 
-    if ((*args == '\0') && (*bf2 == '\0'))
+    if (*args == '\0' && *bf2 == '\0')
 	return;
 
     argc = 1;
@@ -366,14 +311,12 @@ void mTestgvpr(GtkWidget * widget, gpointer user_data)
     }
     assert(j == argc);
 
-
     run_gvpr(view->g[view->activeGraph], argc, argv);
     for (i = 1; i < argc; i++)
 	free(argv[i]);
     free(argv);
 }
 
-
 /*
    opens a file open dialog and load a gvpr program to gvpr script text box
    if the current script is modified, user should be informed about it
@@ -423,13 +366,10 @@ void on_gvprbuttonsave_clicked(GtkWidget * widget, gpointer user_data)
     FILE *output_file = NULL;
     agxbuf xbuf;
     GtkTextBuffer *gtkbuf;	/*GTK buffer from glade GUI */
-    int charcnt;
     char *bf2;
     GtkTextIter startit;
     GtkTextIter endit;
 
-
-
     agxbinit(&xbuf, SMALLBUF, NULL);
     /*file name should be returned in xbuf */
     if (savefiledlg(0, NULL, &xbuf)) {
@@ -439,18 +379,13 @@ void on_gvprbuttonsave_clicked(GtkWidget * widget, gpointer user_data)
 		gtk_text_view_get_buffer((GtkTextView *)
 					 glade_xml_get_widget(xml,
 							      "gvprtextinput"));
-	    charcnt = gtk_text_buffer_get_char_count(gtkbuf);
 	    gtk_text_buffer_get_start_iter(gtkbuf, &startit);
 	    gtk_text_buffer_get_end_iter(gtkbuf, &endit);
 	    bf2 = gtk_text_buffer_get_text(gtkbuf, &startit, &endit, 0);
 	    fprintf(output_file, "%s", bf2);
 	    fclose(output_file);
-
 	}
 
-
 	/*Code has not been completed for this function yet */
     }
-
-
 }
