@@ -15,11 +15,6 @@
 #include "windows.h"
 #endif
 #endif
-#ifdef	_WIN32			//this  is needed on _WIN32 to get libglade see the callback
-#define _BB  __declspec(dllexport)
-#else
-#define _BB
-#endif
 
 #include <xdot/xdot.h>
 #include <gtk/gtk.h>
@@ -64,33 +59,10 @@ typedef struct _ArcBall_t ArcBall_t;
 #define MM_FISHEYE_PICK		22  /*fisheye select foci point*/
 #define MM_POLYGON_SELECT   30
 
-
-
-#define GLOBAL_Z_OFFSET			0.001
-
 #define MAX_ZOOM	500.0f
 #define MIN_ZOOM	0.005f
-#define ZOOM_STEPS	100
 
-#define ZOOM_STEP	0.5
 #define DEG2RAD  G_PI/180
-#define RAD2DEG	  1/0.017453292519943
-
-#define UNHIGHLIGHTED_ALPHA	0.3
-#define Z_FORWARD_PLANE -0.00201
-#define Z_MIDDLE_PLANE 0.0000
-#define Z_BACK_PLANE -0.00199
-
-#define NODE_ZOOM_LIMIT	-25.3
-#define NODE_CIRCLE_LIMIT	-7.3
-
-#define GL_DOTSIZE_CONSTANT -18
-#define DOUBLE_IT 10.00
-
-
-#define SPHERE_SLICE_COUNT 6
-#define DOT_SIZE_CORRECTION_FAC 0.3
-
 
 #define EXPAND_CAPACITY_VALUE 50
 #define DEFAULT_ATTR_LIST_CAPACITY 100
@@ -130,7 +102,6 @@ typedef struct
 }attr_list;
 
 
-    typedef enum { nodshapedot, nodeshapecircle } node_shape;
     typedef enum { leftmousebutton, rightmousebutton,
 	    thirdmousebutton } clicked_mouse_button;
     typedef enum { MOUSE_ROTATE_X, MOUSE_ROTATE_Y, MOUSE_ROTATE_XY,
@@ -183,14 +154,6 @@ typedef struct
 	colorschema *s;
     } colorschemaset;
 
-    typedef enum {
-	VT_NONE,
-	VT_XDOT,
-	VT_TOPVIEW,
-	VT_TOPFISH,
-    } viewtype_t;
-
-
     typedef enum {
 	GVE_NONE = -1,
 	GVE_GRAPH,
@@ -495,26 +458,6 @@ typedef struct
 	NUM_COLS
     };
 
-
-/*    typedef struct _mouse_attr {
-	int mouse_down;
-	int mouse_mode;
-	int pick;
-	float mouse_X;
-	float mouse_Y;
-	float begin_x;
-	float begin_y;
-	float dx;
-	float dy;
-	float GLX;	
-	float GLpos.y;
-	float GLpos.z;
-	mouse_rotate_axis rotate_axis;
-	clicked_mouse_button button;
-    } mouse_attr;*/
-
-
-
     typedef struct _attribute {
 	char Type;
 	char *Name;
@@ -597,17 +540,12 @@ typedef struct
 	int bdVisible;		//if borders are visible (boundries of the drawing,
 	/*border coordinates, needs to be calculated for each graph */
 
-	/*randomize node colors or use default node color */
-	int rndNodeColor;
-
-	/*randomize edge colors or use default edge color */
-	int rndEdgeColor;
 	/*Font Size */
 	float FontSize;
 
 
-	float bdxLeft, bdyTop, bdzTop;
-	float bdxRight, bdyBottom, bdzBottom;
+	float bdxLeft, bdyTop;
+	float bdxRight, bdyBottom;
 
 	/*reserved , not being used yet */
 	GEunit unit;		//default pixels :0  
@@ -621,11 +559,6 @@ typedef struct
 	/*active graph */
 	int activeGraph;
 
-	/*texture data */
-	int texture;		/*1 texturing enabled, 0 disabled */
-	/*opengl depth value to convert mouse to GL coords */
-	float GLDepth;
-
 	/*stores the info about status of mouse,pressed? what button ? where? */
 //	mouse_attr mouse;
 	glCompMouse mouse;
@@ -641,25 +574,13 @@ typedef struct
 	viewport_camera **cameras;
 	int camera_count;	//number of cameras
 	int active_camera;
-	viewport_camera *selected_camera;	//selected camera does not have to nec. be active one 
-
-	/*data attributes are read from graph's attributes DataAttribute1 and DataAttribute2 */
-	char *node_data_attribute1;	/*for topview graphs this is the node data attribute to put as label */
-	char *node_data_attribute2;	/*for topview graphs this is the node data attribute to be stored and used for something else */
 
 	/*0 advanced users with editing options 1 nonice users just navigate (glmenu system) */
 	int topviewusermode;
-	/*this should not be confused with graphviz node shapes, it can be dot or circles (dots are rendered mych faster, circle looks handsome, if graph is ulta large go with dot */
-//      node_shape nodeshape;
-	/*if true and nodeshape is nodeshapecircle , radius of nodes changes with degree */
-	int nodesizewithdegree;
 
 	/*open gl canvas, used to be a globa variable before looks better wrapped in viewinfo */
 	GtkWidget *drawing_area;
 
-	/*some boolean variable for variety hacks used in the software */
-	int SignalBlock;
-
 	/*Topview data structure, refer topview.h for more info */
 	topview *Topview;
 	/*timer for animations */
@@ -670,7 +591,6 @@ typedef struct
 	GTimer *timer3;
 	int active_frame;
 	int total_frames;
-	int frame_length;
 	/*lately added */
 	int drawnodes;
 	int drawedges;
@@ -686,23 +606,13 @@ typedef struct
 	int labelshownodes;
 	int labelshowedges;
 
-	viewtype_t dfltViewType;
-	gvk_layout dfltEngine;
-	GtkTextBuffer *consoleText;
-	float FontSizeConst;
 	glCompSet *widgets;	//for novice user open gl menu
-	int visiblenodecount;	/*helper variable to know the number of the nodes being rendered, good data to optimize speed */
 	char *initFileName;	//file name from command line
 	int initFile;
 	int drawSplines;
 	colorschemaset *colschms;
-	char *glade_file;
 	char* temp;
 	char *template_file;
-	char *attr_file;
-	int flush;
-	gvprscript *scripts;
-	int script_count;	/*# of scripts */
 	GtkComboBox *graphComboBox;	/*pointer to graph combo box at top right */
 	ArcBall_t *arcball;
 	keymap_t keymap;
@@ -719,17 +629,11 @@ typedef struct
 
     extern ViewInfo *view;
     extern GtkMessageDialog *Dlg;
-    extern int respond;
     extern char *smyrnaPath(char *suffix);
     extern char *smyrnaGlade;
 
     extern void glexpose(void);
 
-    extern char *layout2s(gvk_layout gvkl);
-    extern gvk_layout s2layout(char *s);
-    extern char *element2s(gve_element);
-    extern unsigned char SmrynaVerbose;
-
 #ifdef __cplusplus
 }				/* end extern "C" */
 #endif
