@@ -8,6 +8,7 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
+#include <assert.h>
 #include "topviewfuncs.h"
 #include <cgraph/cgraph.h>
 #include "smyrna_utils.h"
@@ -76,9 +77,6 @@ static void set_boundaries(Agraph_t * g, topview * t)
     view->bdyTop = top;
     view->bdxRight = right;
     view->bdyBottom = bottom;
-
-    view->bdzTop = 0;
-    view->bdzBottom = 0;
 }
 
 static void draw_xdot(xdot* x,float base_z)
@@ -162,7 +160,8 @@ static int object_color(void* obj,glCompColor* c)
 	Alpha=getAttrFloat(g,objg,"defaultedgealpha",1);
 	vis = GE_visible (objg);
     }
-    else if(objType==AGNODE) {
+    else {
+	assert(objType == AGNODE);
 	Alpha=getAttrFloat(g,objg,"defaultnodealpha",1);
 	vis = GN_visible (objg);
     }
@@ -273,7 +272,7 @@ static void renderSelectedNodes(Agraph_t * g)
 
     for (v = agfstnode(g); v; v = agnxtnode(g, v)) 
     {
-	if(!ND_selected(v));
+	if(!ND_selected(v))
 	    continue;
 	x=parseXdotwithattrs(v);
 	draw_xdot(x,-1);
@@ -888,10 +887,7 @@ void initSmGraph(Agraph_t * g,topview* rv)
     /*set topologilca fisheye to NULL */
     rv->fisheyeParams.h = '\0';
 
-    if (view->dfltViewType == VT_TOPFISH)
-	rv->fisheyeParams.active = 1;
-    else
-	rv->fisheyeParams.active = 0;
+    rv->fisheyeParams.active = 0;
     rv->cache.node_id=-1;
     rv->cache.selnode_id=-1;
     rv->cache.edge_id=-1;
