@@ -34,12 +34,9 @@
 
 static colorschemaset *create_color_theme(int themeid);
 
-#define countof( array ) ( sizeof( array )/sizeof( array[0] ) )
-
 ViewInfo *view;
 /* these two global variables should be wrapped in something else */
 GtkMessageDialog *Dlg;
-int respond;
 
 static void clear_viewport(ViewInfo * view)
 {
@@ -208,8 +205,6 @@ void set_viewport_settings_from_template(ViewInfo * view, Agraph_t * g)
     view->drawedgelabels=atoi(get_attribute_value("labelshowedges", view, g));
     view->nodeScale=atof(get_attribute_value("nodesize", view, g))*.30;
 
-    view->FontSizeConst = 0;	//this will be calculated later in topview.c while calculating optimum font size
-
     view->glutfont =
 	get_glut_font(atoi(get_attribute_value("labelglutfont", view, g)));
     colorxlate(get_attribute_value("nodelabelcolor", view, g), &cl,
@@ -258,13 +253,9 @@ static void get_data_dir(void)
 {
     if (view->template_file) {
 	free(view->template_file);
-	free(view->glade_file);
-	free(view->attr_file);
     }
 
     view->template_file = strdup(smyrnaPath("template.dot"));
-    view->glade_file = strdup(smyrnaPath("smyrna.glade"));
-    view->attr_file = strdup(smyrnaPath("attrs.txt"));
 }
 
 void init_viewport(ViewInfo * view)
@@ -280,7 +271,7 @@ void init_viewport(ViewInfo * view)
 		view->template_file);
 	exit(-1);
     } 
-    view->systemGraphs.def_attrs = agread(input_file, 0);
+    view->systemGraphs.def_attrs = agread(input_file, NULL);
     fclose (input_file);
 
     if (!view->systemGraphs.def_attrs) {
@@ -297,7 +288,7 @@ void init_viewport(ViewInfo * view)
 	exit(-1);
 
     }
-    view->systemGraphs.attrs_widgets = agread(input_file2, 0);
+    view->systemGraphs.attrs_widgets = agread(input_file2, NULL);
     fclose (input_file2);
     if (!(view->systemGraphs.attrs_widgets )) {
 	fprintf(stderr,"could not load default attribute widgets graph file \"%s\"\n",smyrnaPath("attr_widgets.dot"));
@@ -311,8 +302,6 @@ void init_viewport(ViewInfo * view)
     view->bdxRight = 500;
     view->bdyBottom = 0;
     view->bdyTop = 500;
-    view->bdzBottom = 0;
-    view->bdzTop = 0;
 
     view->borderColor.R = 1;
     view->borderColor.G = 0;
@@ -355,14 +344,12 @@ void init_viewport(ViewInfo * view)
     view->LineWidth = 1;
 
     //default view settings , camera is not active
-    view->GLDepth = 1;		//should be set before GetFixedOGLPos(int x, int y,float kts) funtion is used!!!!
     view->panx = 0;
     view->pany = 0;
     view->panz = 0;
 
 
     view->zoom = -20;
-    view->texture = 1;
     view->FontSize = 52;
 
     view->topviewusermode = TOP_VIEW_USER_NOVICE_MODE;	//for demo
@@ -376,7 +363,6 @@ void init_viewport(ViewInfo * view)
     view->fmg.active = 0;
     view->mouse.down = 0;
     view->activeGraph = -1;
-    view->SignalBlock = 0;
     view->Topview = GNEW(topview);
     view->Topview->fisheyeParams.fs = 0;
     view->Topview->xDot=NULL;
@@ -402,7 +388,6 @@ void init_viewport(ViewInfo * view)
     g_timer_stop(view->timer);
     view->active_frame = 0;
     view->total_frames = 1500;
-    view->frame_length = 1;
     /*add a call back to the main() */
     g_timeout_add_full((gint) G_PRIORITY_DEFAULT, (guint) 100,
 		       gl_main_expose, NULL, NULL);
@@ -410,12 +395,9 @@ void init_viewport(ViewInfo * view)
     view->camera_count = 0;
     view->active_camera = -1;
     set_viewport_settings_from_template(view, view->systemGraphs.def_attrs);
-    view->dfltViewType = VT_NONE;
-    view->dfltEngine = GVK_NONE;
     view->Topview->Graphdata.GraphFileName = (char *) 0;
     view->Topview->Graphdata.Modified = 0;
     view->colschms = NULL;
-    view->flush = 1;
     view->arcball = NEW(ArcBall_t);
     view->keymap.down=0;
     load_mouse_actions (view);
@@ -655,20 +637,6 @@ int save_as_graph(void)
     return 0;
 }
 
-int setGdkColor(GdkColor * c, char *color)
-{
-    gvcolor_t cl;
-    if (color != '\0') {
-	colorxlate(color, &cl, RGBA_DOUBLE);
-	c->red = (int) (cl.u.RGBA[0] * 65535.0);
-	c->green = (int) (cl.u.RGBA[1] * 65535.0);
-	c->blue = (int) (cl.u.RGBA[2] * 65535.0);
-	return 1;
-    } else
-	return 0;
-
-}
-
 void glexpose(void)
 {
     expose_event(view->drawing_area, NULL, NULL);
@@ -717,35 +685,22 @@ void getcolorfromschema(colorschemaset * sc, float l, float maxl,
 /* set_color_theme_color:
  * Convert colors as strings to RGB
  */
-static void set_color_theme_color(colorschemaset * sc, char **colorstr, int smooth)
+static void set_color_theme_color(colorschemaset * sc, char **colorstr)
 {
     int ind;
     int colorcnt = sc->schemacount;
     gvcolor_t cl;
     float av_perc;
 
-    sc->smooth = smooth;
-    if (smooth) {
-	av_perc = 1.0 / (float) (colorcnt-1);
-	for (ind = 0; ind < colorcnt; ind++) {
-	    colorxlate(colorstr[ind], &cl, RGBA_DOUBLE);
-	    sc->s[ind].c.R = cl.u.RGBA[0];
-	    sc->s[ind].c.G = cl.u.RGBA[1];
-	    sc->s[ind].c.B = cl.u.RGBA[2];
-	    sc->s[ind].c.A = cl.u.RGBA[3];
-	    sc->s[ind].perc = ind * av_perc;
-	}
-    }
-    else {
-	av_perc = 1.0 / (float) (colorcnt);
-	for (ind = 0; ind < colorcnt; ind++) {
-	    colorxlate(colorstr[ind], &cl, RGBA_DOUBLE);
-	    sc->s[ind].c.R = cl.u.RGBA[0];
-	    sc->s[ind].c.G = cl.u.RGBA[1];
-	    sc->s[ind].c.B = cl.u.RGBA[2];
-	    sc->s[ind].c.A = cl.u.RGBA[3];
-	    sc->s[ind].perc = (ind+1) * av_perc;
-	}
+    sc->smooth = 1;
+    av_perc = 1.0 / (float) (colorcnt-1);
+    for (ind = 0; ind < colorcnt; ind++) {
+        colorxlate(colorstr[ind], &cl, RGBA_DOUBLE);
+        sc->s[ind].c.R = cl.u.RGBA[0];
+        sc->s[ind].c.G = cl.u.RGBA[1];
+        sc->s[ind].c.B = cl.u.RGBA[2];
+        sc->s[ind].c.A = cl.u.RGBA[3];
+        sc->s[ind].perc = ind * av_perc;
     }
 }
 
@@ -795,7 +750,7 @@ static colorschemaset *create_color_theme(int themeid)
 
     s->schemacount = palette[themeid].cnt;
     s->s = N_NEW(s->schemacount,colorschema);
-    set_color_theme_color(s, palette[themeid].colors, 1);
+    set_color_theme_color(s, palette[themeid].colors);
 
     return s;
 }
