@@ -25,6 +25,7 @@
 #include <neatogen/neatoprocs.h>
 #include <ingraphs/ingraphs.h>
 #include <pack/pack.h>
+#include <stddef.h>
 
 #if defined(_WIN32)
   __declspec(dllimport)
@@ -95,19 +96,13 @@ static void usage(int v)
     exit(v);
 }
 
-static FILE *openFile(char *name, char *mode)
+static FILE *openFile(const char *name)
 {
     FILE *fp;
-    char *modestr;
 
-    fp = fopen(name, mode);
+    fp = fopen(name, "w");
     if (!fp) {
-	if (*mode == 'r')
-	    modestr = "reading";
-	else
-	    modestr = "writing";
-	fprintf(stderr, "gvpack: could not open file %s for %s\n",
-		name, modestr);
+	fprintf(stderr, "gvpack: could not open file %s for writing\n", name);
 	exit(1);
     }
     return (fp);
@@ -217,7 +212,7 @@ static void init(int argc, char *argv[], pack_info* pinfo)
 	case 'o':
 	    if (outfp != NULL)
 		fclose(outfp);
-	    outfp = openFile(optarg, "w");
+	    outfp = openFile(optarg);
 	    break;
 	case 'u':
 	    pinfo->mode = l_undef;
@@ -759,7 +754,7 @@ static Agraph_t *cloneGraph(Agraph_t ** gs, int cnt, GVC_t * gvc)
 
 static Agraph_t *gread(FILE * fp)
 {
-    return agread(fp, (Agdisc_t *) 0);
+    return agread(fp, NULL);
 }
 
 /* readGraphs:
