@@ -8,8 +8,8 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#ifndef ATT_GRAPHPVT_H
-#define ATT_GRAPHPVT_H 1
+#pragma once
+
 #define _BLD_cgraph 1
 
 #ifdef _WIN32
@@ -29,6 +29,7 @@
 #include	 	<ctype.h>
 #include		<sys/types.h>
 #include		<stdarg.h>
+#include		<stdbool.h>
 #include		<stdlib.h>
 #include		<string.h>
 #ifdef HAVE_UNISTD_H
@@ -37,9 +38,10 @@
 #include <assert.h>
 #include <stdint.h>
 
-#ifndef streq
-#define streq(s,t)		((*s == *t) && !strcmp((s),(t)))
-#endif
+static inline bool streq(const char *a, const char *b) {
+  return strcmp(a, b) == 0;
+}
+
 #define NOTUSED(var)	(void) var
 
 #define NILgraph			NIL(Agraph_t*)
@@ -146,15 +148,11 @@ void agmethod_init(Agraph_t * g, void *obj);
 void agmethod_upd(Agraph_t * g, void *obj, Agsym_t * sym);
 void agmethod_delete(Agraph_t * g, void *obj);
 
-#define CB_INITIALIZE	100
-#define CB_UPDATE		101
-#define CB_DELETION		102
+typedef enum { CB_INITIALIZE, CB_UPDATE, CB_DELETION, } cb_t;
 void agsyspushdisc(Agraph_t * g, Agcbdisc_t * cb, void *state, int stack);
 int agsyspopdisc(Agraph_t * g, Agcbdisc_t * cb, int stack);
-void agrecord_callback(Agraph_t * g, Agobj_t * obj, int kind,
+void agrecord_callback(Agraph_t * g, Agobj_t * obj, cb_t kind,
 		       Agsym_t * optsym);
 void aginitcb(Agraph_t * g, void *obj, Agcbstack_t * disc);
 void agupdcb(Agraph_t * g, void *obj, Agsym_t * sym, Agcbstack_t * disc);
 void agdelcb(Agraph_t * g, void *obj, Agcbstack_t * disc);
-
-#endif				/* ATT_GRAPHPVT_H */
