@@ -8,33 +8,19 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-/* this is to get the following win32 DLL junk to work.
- * if ever tempted to remove this, first please read:
- * http://joel.editthispage.com/stories/storyReader$47
- */
-#ifndef GLOBALS_H
-#define GLOBALS_H
+#pragma once
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-#ifndef __CYGWIN__
-#if defined(GVDLL)
-#if !defined(_BLD_gvc)
-#define DECLSPEC	__declspec(dllimport)
-#else
+#if defined(GVDLL) || defined(WIN32_DLL)
+#if defined(GVC_EXPORTS) || defined(_BLD_gvc)
 #define DECLSPEC __declspec(dllexport)
-#endif
-#endif
-#endif
-/*visual studio*/
-#ifdef _WIN32
-#ifndef GVC_EXPORTS
+#else
 #define DECLSPEC __declspec(dllimport)
 #endif
 #endif
-/*end visual studio*/
 
 #ifndef DECLSPEC
 #define DECLSPEC /* nothing */
@@ -116,4 +102,3 @@ extern "C" {
 #ifdef __cplusplus
 }
 #endif
-#endif
