@@ -1,6 +1,3 @@
-/* $Id$Revision: */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,15 +5,14 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 /*Open GL texture handling and storing mechanism
   includes glPanel,glCompButton,glCompCustomButton,clCompLabel,glCompStyle
 */
 
-#ifndef glCompFontURE_H
-#define glCompFontURE_H
+#pragma once
 
 #ifdef _WIN32
 #include "windows.h"
@@ -24,7 +20,7 @@
 #include <stdio.h>
 #include <GL/gl.h>
 #include <GL/glu.h>
-#include "glcompdefs.h"
+#include <glcomp/glcompdefs.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -42,4 +38,3 @@ extern "C" {
 #ifdef __cplusplus
 }
 #endif
-#endif
