@@ -8,8 +8,8 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#ifndef GLPANGOFONT_H
-#define GLPANGOFONT_H
+#pragma once
+
 #include <cairo/cairo.h>
 #include <pango/pangocairo.h>
 #include <png.h>
@@ -30,4 +30,3 @@ extern "C" {
 #ifdef __cplusplus
 }
 #endif
-#endif
