@@ -52,13 +52,14 @@ static uint64_t crc;
 #include <gvc/gvcint.h>
 #include <gvc/gvcproc.h>
 #include <common/logic.h>
+#include <common/utils.h>
 #include <gvc/gvio.h>
 
 static const int PAGE_ALIGN = 4095;		/* align to a 4K boundary (less one), typical for Linux, Mac OS X and Windows memory allocation */
 
 static size_t gvwrite_no_z (GVJ_t * job, const char *s, size_t len)
 {
-    if (job->gvc->write_fn)   /* externally provided write dicipline */
+    if (job->gvc->write_fn)   /* externally provided write discipline */
 	return (job->gvc->write_fn)(job, s, len);
     if (job->output_data) {
 	if (len > job->output_data_allocated - (job->output_data_position + 1)) {
@@ -72,7 +73,7 @@ static size_t gvwrite_no_z (GVJ_t * job, const char *s, size_t len)
 	}
 	memcpy(job->output_data + job->output_data_position, s, len);
         job->output_data_position += len;
-	job->output_data[job->output_data_position] = '\0'; /* keep null termnated */
+	job->output_data[job->output_data_position] = '\0'; /* keep null terminated */
 	return len;
     }
     else {
@@ -100,7 +101,7 @@ static void auto_output_filename(GVJ_t *job)
         + strlen(gidx)                  /* "", ".2", ".3", ".4", ... */
         + 1                             /* "." */
         + strlen(job->output_langname)  /* e.g. "png" */
-        + 1;                            /* null terminaor */
+        + 1;                            /* null terminator */
     if (bufsz < len) {
             bufsz = len + 10;
             buf = realloc(buf, bufsz * sizeof(char));
@@ -272,6 +273,11 @@ int gvputs(GVJ_t * job, const char *s)
     return 1;
 }
 
+int gvputs_xml(GVJ_t *job, const char *s) {
+  const xml_flags_t flags = {.dash = 1, .nbsp = 1};
+  return xml_escape(s, flags, (int (*)(void *, const char *))gvputs, job);
+}
+
 int gvputc(GVJ_t * job, int c)
 {
     const char cc = c;
