@@ -1,6 +1,3 @@
-/* $Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,7 +5,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 
@@ -21,8 +18,8 @@
 ******************************************/
 
 
-#include "bfs.h"
-#include "dijkstra.h"
+#include <neatogen/bfs.h>
+#include <neatogen/dijkstra.h>
 #include <limits.h>
 #include <stdlib.h>
 /* #include <math.h> */
@@ -31,8 +28,6 @@
 
 typedef DistType Word;
 
-#define LOOP while(TRUE)
-
 /* This heap class is suited to the Dijkstra alg.
    data[i]=vertexNum <==> index[vertexNum]=i
 */
@@ -77,21 +72,9 @@ static void heapify(heap * h, int i, int index[], Word dist[])
     }
 }
 
-#ifdef OBSOLETE
-/* originally, the code called mkHeap to allocate space, then
- * initHeap to realloc the space. This is silly.
- * Now we just call initHeap.
- */
-static void mkHeap(heap * h, int size)
-{
-    h->data = N_GNEW(size, int);
-    h->heapSize = 0;
-}
-#endif
-
 static void freeHeap(heap * h)
 {
-    if (h->data) free(h->data);
+    free(h->data);
 }
 
 static void
@@ -99,7 +82,6 @@ initHeap(heap * h, int startVertex, int index[], Word dist[], int n)
 {
     int i, count;
     int j;    /* We cannot use an unsigned value in this loop */
-    /* h->data=(int*) realloc(h->data, (n-1)*sizeof(int)); */
     if (n == 1) h->data = NULL;
     else h->data = N_GNEW(n - 1, int);
     h->heapSize = n - 1;
@@ -160,10 +142,7 @@ void dijkstra(int vertex, vtx_data * graph, int n, DistType * dist)
     DistType closestDist, prevClosestDist = INT_MAX;
     static int *index;
 
-#ifdef OBSOLETE
-    mkHeap(&H, n);
-#endif
-    index = (int *) realloc(index, n * sizeof(int));
+    index = realloc(index, n * sizeof(int));
 
     /* initial distances with edge weights: */
     for (i = 0; i < n; i++)
@@ -223,8 +202,7 @@ dijkstra_bounded(int vertex, vtx_data * graph, int n, DistType * dist,
     num_visited_nodes =
 	bfs_bounded(vertex, graph, n, dist, &Q, bound, visited_nodes);
     if (size < n) {
-	node_in_neighborhood =
-	    (boolean *) realloc(node_in_neighborhood, n * sizeof(boolean));
+	node_in_neighborhood = realloc(node_in_neighborhood, n * sizeof(boolean));
 	for (i = size; i < n; i++) {
 	    node_in_neighborhood[i] = FALSE;
 	}
@@ -235,10 +213,7 @@ dijkstra_bounded(int vertex, vtx_data * graph, int n, DistType * dist,
     }
 
 
-#ifdef OBSOLETE
-    mkHeap(&H, n);
-#endif
-    index = (int *) realloc(index, n * sizeof(int));
+    index = realloc(index, n * sizeof(int));
 
     /* initial distances with edge weights: */
     for (i = 0; i < n; i++)	/* far, TOO COSTLY (O(n))! */
@@ -365,9 +340,6 @@ void dijkstra_f(int vertex, vtx_data * graph, int n, float *dist)
     float closestDist;
     int *index;
 
-#ifdef OBSOLETE
-    mkHeap(&H, n);
-#endif
     index = N_GNEW(n, int);
 
     /* initial distances with edge weights: */
@@ -394,3 +366,49 @@ void dijkstra_f(int vertex, vtx_data * graph, int n, float *dist)
     freeHeap(&H);
     free(index);
 }
+
+// single source shortest paths that also builds terms as it goes
+// mostly copied from dijkstra_f above
+// returns the number of terms built
+int dijkstra_sgd(graph_sgd *graph, int source, term_sgd *terms) {
+    heap h;
+    int *indices = N_GNEW(graph->n, int);
+    float *dists = N_GNEW(graph->n, float);
+    int i;
+    for (i=0; i<graph->n; i++) {
+        dists[i] = MAXFLOAT;
+    }
+    dists[source] = 0;
+    for (i=graph->sources[source]; i<graph->sources[source+1]; i++) {
+        int target = graph->targets[i];
+        dists[target] = graph->weights[i];
+    }
+    initHeap_f(&h, source, indices, dists, graph->n);
+
+    int closest = 0, offset = 0;
+    while (extractMax_f(&h, &closest, indices, dists)) {
+        float d = dists[closest];
+        if (d == MAXFLOAT) {
+            break;
+        }
+        // if the target is fixed then always create a term as shortest paths are not calculated from there
+        // if not fixed then only create a term if the target index is lower
+        if (graph->pinneds[closest] || closest<source) {
+            terms[offset].i = source;
+            terms[offset].j = closest;
+            terms[offset].d = d;
+            terms[offset].w = 1 / (d*d);
+            offset++;
+        }
+        for (i=graph->sources[closest]; i<graph->sources[closest+1]; i++) {
+            int target = graph->targets[i];
+            float weight = graph->weights[i];
+            increaseKey_f(&h, target, d+weight, indices, dists);
+        }
+    }
+    freeHeap(&h);
+    free(indices);
+    free(dists);
+    return offset;
+}
+
