@@ -1,6 +1,3 @@
-/* $Id$Revision: */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property 
  * All rights reserved. This program and the accompanying materials
@@ -8,11 +5,10 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#ifndef MULTISPLINE_H
-#define MULTISPLINE_H
+#pragma once
 
 #include <render.h>
 #include <pathutil.h>
@@ -22,5 +18,3 @@ typedef struct router_s router_t;
 extern void freeRouter (router_t* rtr);
 extern router_t* mkRouter (Ppoly_t** obs, int npoly);
 extern int makeMultiSpline(graph_t* g, edge_t* e, router_t * rtr, int);
-
-#endif
