@@ -1,6 +1,3 @@
-/* Id$ $Revision$ */
-/* vim:set shiftwidth=4 ts=8: */
-
 /*************************************************************************
  * Copyright (c) 2011 AT&T Intellectual Property
  * All rights reserved. This program and the accompanying materials
@@ -8,7 +5,7 @@
  * which accompanies this distribution, and is available at
  * http://www.eclipse.org/legal/epl-v10.html
  *
- * Contributors: See CVS logs. Details at http://www.graphviz.org/
+ * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
 
@@ -20,14 +17,16 @@
 #endif
 #include <ctype.h>
 
-#include "neato.h"
-#include "pack.h"
-#include "stress.h"
+#include <neatogen/neato.h>
+#include <pack/pack.h>
+#include <neatogen/stress.h>
 #ifdef DIGCOLA
-#include "digcola.h"
+#include <neatogen/digcola.h>
 #endif
-#include "kkutils.h"
-#include "pointset.h"
+#include <neatogen/kkutils.h>
+#include <common/pointset.h>
+#include <neatogen/sgd.h>
+#include <cgraph/strcasecmp.h>
 
 #ifndef HAVE_SRAND48
 #define srand48 srand
@@ -66,8 +65,7 @@ int user_pos(attrsym_t * posptr, attrsym_t * pinptr, node_t * np, int nG)
     p = agxget(np, posptr);
     if (p[0]) {
 	c = '\0';
-	if ((Ndim >= 3) &&
-            (sscanf(p, "%lf,%lf,%lf%c", pvec, pvec+1, pvec+2, &c) >= 3)){
+	if (Ndim >= 3 && sscanf(p, "%lf,%lf,%lf%c", pvec, pvec+1, pvec+2, &c) >= 3){
 	    ND_pinned(np) = P_SET;
 	    if (PSinputscale > 0.0) {
 		int i;
@@ -76,7 +74,7 @@ int user_pos(attrsym_t * posptr, attrsym_t * pinptr, node_t * np, int nG)
 	    }
 	    if (Ndim > 3)
 		jitter_d(np, nG, 3);
-	    if ((c == '!') || (pinptr && mapbool(agxget(np, pinptr))))
+	    if (c == '!' || (pinptr && mapbool(agxget(np, pinptr))))
 		ND_pinned(np) = P_PIN;
 	    return TRUE;
 	}
@@ -85,10 +83,10 @@ int user_pos(attrsym_t * posptr, attrsym_t * pinptr, node_t * np, int nG)
 	    if (PSinputscale > 0.0) {
 		int i;
 		for (i = 0; i < Ndim; i++)
-		    pvec[i] = pvec[i] / PSinputscale;
+		    pvec[i] /= PSinputscale;
 	    }
 	    if (Ndim > 2) {
-		if (N_z && (p = agxget(np, N_z)) && (sscanf(p,"%lf",&z) == 1)) {
+		if (N_z && (p = agxget(np, N_z)) && sscanf(p,"%lf",&z) == 1) {
 		    if (PSinputscale > 0.0) {
 			pvec[2] = z / PSinputscale;
 		    }
@@ -99,7 +97,7 @@ int user_pos(attrsym_t * posptr, attrsym_t * pinptr, node_t * np, int nG)
 		else
 		    jitter3d(np, nG);
 	    }
-	    if ((c == '!') || (pinptr && mapbool(agxget(np, pinptr))))
+	    if (c == '!' || (pinptr && mapbool(agxget(np, pinptr))))
 		ND_pinned(np) = P_PIN;
 	    return TRUE;
 	} else
@@ -131,7 +129,7 @@ static void neato_init_node_edge(graph_t * g)
 
 static void neato_cleanup_graph(graph_t * g)
 {
-    if (Nop || (Pack < 0)) {
+    if (Nop || Pack < 0) {
 	free_scan_graph(g);
 	free(GD_clust(g));
     }
@@ -163,7 +161,7 @@ static int numFields(unsigned char *pos)
 	    pos++;		/* skip white space */
 	if ((c = *pos)) { /* skip token */
 	    cnt++;
-	    while ((c = *pos) && !isspace(c) && (c != ';'))
+	    while ((c = *pos) && !isspace(c) && c != ';')
 		pos++;
 	}
     } while (isspace(c));
@@ -175,7 +173,7 @@ static void set_label(void* obj, textlabel_t * l, char *name)
     double x, y;
     char *lp;
     lp = agget(obj, name);
-    if (lp && (sscanf(lp, "%lf,%lf", &x, &y) == 2)) {
+    if (lp && sscanf(lp, "%lf,%lf", &x, &y) == 2) {
 	l->pos = pointfof(x, y);
 	l->set = TRUE;
     }
@@ -210,7 +208,6 @@ static cluster_data* cluster_map(graph_t *mastergraph, graph_t *g)
             *cn = agnnodes(subg);
             cdata->nvars += *cn;
             c = *cs++ = N_GNEW(*cn++,int);
-            /* fprintf(stderr,"Cluster with %d nodes...\n",agnnodes(subg)); */
             for (n = agfstnode(subg); n; n = agnxtnode(subg, n)) {
                 node_t *gn;
                 int ind = 0;
@@ -218,7 +215,6 @@ static cluster_data* cluster_map(graph_t *mastergraph, graph_t *g)
                     if(AGSEQ(gn)==AGSEQ(n)) break;
                     ind++;
                 }
-                /* fprintf(stderr,"  node=%s, id=%d, ind=%d\n",agnameof(n),n->id,ind); */
                 *c++=ind;
                 assigned[ind]=TRUE;
                 cdata->ntoplevel--;
@@ -294,7 +290,7 @@ static int user_spline(attrsym_t * E_pos, edge_t * e)
 
 	npts = numFields((unsigned char *) pos);	/* count potential points */
 	n = npts;
-	if ((n < 4) || (n % 3 != 1)) {
+	if (n < 4 || n % 3 != 1) {
 	    gv_free_splines(e);
 	    if (!warned) {
 		warned = 1;
@@ -315,7 +311,7 @@ static int user_spline(attrsym_t * E_pos, edge_t * e)
 		gv_free_splines(e);
 		return 0;
 	    }
-	    pos = pos + nc;
+	    pos += nc;
 	    pp->x = x;
 	    pp->y = y;
 	    pp++;
@@ -381,7 +377,7 @@ static pos_edge nop_init_edges(Agraph_t * g)
 	return AllEdges;
 
     E_pos = agfindedgeattr(g, "pos");
-    if (!E_pos || (Nop < 2))
+    if (!E_pos || Nop < 2)
 	return NoEdges;
 
     for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
@@ -560,7 +556,7 @@ int init_nop(Agraph_t * g, int adjust)
     else
 	haveBackground = 0;
 
-    if (adjust && (Nop == 1) && !haveBackground)
+    if (adjust && Nop == 1 && !haveBackground)
 	didAdjust = adjustNodes(g);
 
     if (didAdjust) {
@@ -583,17 +579,17 @@ int init_nop(Agraph_t * g, int adjust)
 	node_t *n;
 	State = GVSPLINES;
 	for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
-	    ND_coord(n).x = POINTS_PER_INCH * (ND_pos(n)[0]);
-	    ND_coord(n).y = POINTS_PER_INCH * (ND_pos(n)[1]);
+	    ND_coord(n).x = POINTS_PER_INCH * ND_pos(n)[0];
+	    ND_coord(n).y = POINTS_PER_INCH * ND_pos(n)[1];
 	}
     }
     else {
 	boolean didShift;
-	if (translate && !haveBackground && ((GD_bb(g).LL.x != 0)||(GD_bb(g).LL.y != 0)))
+	if (translate && !haveBackground && (GD_bb(g).LL.x != 0||GD_bb(g).LL.y != 0))
 	    neato_translate (g);
 	didShift = neato_set_aspect(g);
 	/* if we have some edge positions and we either shifted or adjusted, free edge positions */
-	if ((posEdges != NoEdges) && (didShift || didAdjust)) {
+	if (posEdges != NoEdges && (didShift || didAdjust)) {
 	    freeEdgeInfo (g);
 	    posEdges = NoEdges;
 	}
@@ -621,19 +617,16 @@ static void neato_init_graph (Agraph_t * g)
 static int neatoModel(graph_t * g)
 {
     char *p = agget(g, "model");
-    char c;
 
-    if (!p || (!(c = *p)))    /* if p is NULL or "" */
+    if (!p || streq(p, ""))    /* if p is NULL or "" */
 	return MODEL_SHORTPATH;
-    if ((c == 'c') && streq(p, "circuit"))
+    if (streq(p, "circuit"))
 	return MODEL_CIRCUIT;
-    if (c == 's') {
-	if (streq(p, "subset"))
-	    return MODEL_SUBSET;
-	else if (streq(p, "shortpath"))
-	    return MODEL_SHORTPATH;
-    }
-    if ((c == 'm') && streq(p, "mds")) {
+    if (streq(p, "subset"))
+	return MODEL_SUBSET;
+    if (streq(p, "shortpath"))
+	return MODEL_SHORTPATH;
+    if (streq(p, "mds")) {
 	if (agattr(g, AGEDGE, "len", 0))
 	    return MODEL_MDS;
 	else {
@@ -657,11 +650,13 @@ static int neatoMode(graph_t * g)
     int mode = MODE_MAJOR;	/* default mode */
 
     str = agget(g, "mode");
-    if (str && *str) {
+    if (str && !streq(str, "")) {
 	if (streq(str, "KK"))
 	    mode = MODE_KK;
 	else if (streq(str, "major"))
 	    mode = MODE_MAJOR;
+	else if (streq(str, "sgd"))
+		mode = MODE_SGD;
 #ifdef DIGCOLA
 	else if (streq(str, "hier"))
 	    mode = MODE_HIER;
@@ -708,7 +703,7 @@ dfsCycle (vtx_data* graph, int i,int mode, node_t* nodes[])
     /* if mode is IPSEP make it an in-edge
      * at both ends, so that an edge constraint won't be generated!
      */
-    double x = (mode==MODE_IPSEP?-1.0:1.0);
+    double x = mode==MODE_IPSEP?-1.0:1.0;
 
     np = nodes[i];
     ND_mark(np) = TRUE;
@@ -719,7 +714,7 @@ dfsCycle (vtx_data* graph, int i,int mode, node_t* nodes[])
 	hp = nodes[j];
 	if (ND_onstack(hp)) {  /* back edge: reverse it */
             graph[i].edists[e] = x;
-            for (f = 1; (f < graph[j].nedges) &&(graph[j].edges[f] != i); f++) ;
+            for (f = 1; f < graph[j].nedges && graph[j].edges[f] != i; f++) ;
             assert (f < graph[j].nedges);
             graph[j].edists[f] = -1.0;
         }
@@ -794,7 +789,7 @@ static vtx_data *makeGraphData(graph_t * g, int nv, int *nedges, int mode, int m
 	haveWt = FALSE;
     } else {
 	haveLen = agattr(g, AGEDGE, "len", 0) ;
-	haveWt = (E_weight != 0);
+	haveWt = E_weight != 0;
     }
     if (mode == MODE_HIER || mode == MODE_IPSEP)
 	haveDir = TRUE;
@@ -850,7 +845,7 @@ static vtx_data *makeGraphData(graph_t * g, int nv, int *nedges, int mode, int m
 		    graph[i].ewgts[idx] = MAX(ED_dist(ep), curlen);
 		}
 	    } else {
-		node_t *vp = (((agtail(ep)) == np) ? aghead(ep) : agtail(ep));
+		node_t *vp = agtail(ep) == np ? aghead(ep) : agtail(ep);
 		ne++;
 		j++;
 
@@ -867,7 +862,7 @@ static vtx_data *makeGraphData(graph_t * g, int nv, int *nedges, int mode, int m
                     if(s&&!strncmp(s,"none",4)) {
                         *edists++ = 0;
                     } else {
-                        *edists++ = (np == aghead(ep) ? 1.0 : -1.0);
+                        *edists++ = np == aghead(ep) ? 1.0 : -1.0;
                     }
                 }
 #endif
@@ -929,7 +924,7 @@ static void initRegular(graph_t * G, int nG)
     node_t *np;
 
     a = 0.0;
-    da = (2 * M_PI) / nG;
+    da = 2 * M_PI / nG;
     for (np = agfstnode(G); np; np = agnxtnode(G, np)) {
 	ND_pos(np)[0] = nG * Spring_coeff * cos(a);
 	ND_pos(np)[1] = nG * Spring_coeff * sin(a);
@@ -961,7 +956,7 @@ setSeed (graph_t * G, int dflt, long* seedp)
     char *p = agget(G, "start");
     int init = dflt;
 
-    if (!p || (*p == '\0')) return dflt;
+    if (!p || *p == '\0') return dflt;
     if (isalpha(*(unsigned char *)p)) {
 	if (!strncmp(p, SMART, SLEN(SMART))) {
 	    init = INIT_SELF;
@@ -988,7 +983,7 @@ setSeed (graph_t * G, int dflt, long* seedp)
 #else
 	    seed = (unsigned) getpid() ^ (unsigned) time(NULL);
 #endif
-	    sprintf(smallbuf, "%ld", seed);
+	    snprintf(smallbuf, sizeof(smallbuf), "%ld", seed);
 	    agset(G, "start", smallbuf);
 	}
 	*seedp = seed;
@@ -1005,7 +1000,7 @@ setSeed (graph_t * G, int dflt, long* seedp)
 static int checkExp (graph_t * G)
 {
     int exp = late_int(G, agfindgraphattr(G, exp_name), 2, 0);
-    if ((exp == 0) || (exp > 2)) {
+    if (exp == 0 || exp > 2) {
 	agerr (AGWARN, "%s attribute value must be 1 or 2 - ignoring\n", exp_name);
 	exp = 2;
     }
@@ -1029,7 +1024,7 @@ int checkStart(graph_t * G, int nG, int dflt)
 
     seed = 1;
     init = setSeed (G, dflt, &seed);
-    if (N_pos && (init != INIT_RANDOM)) {
+    if (N_pos && init != INIT_RANDOM) {
 	agerr(AGWARN, "node positions are ignored unless start=random\n");
     }
     if (init == INIT_REGULAR) initRegular(G, nG);
@@ -1123,11 +1118,11 @@ void dumpOpts (ipsep_options* opp, int nv)
  * mode will be MODE_MAJOR, MODE_HIER or MODE_IPSEP
  */
 static void
-majorization(graph_t *mg, graph_t * g, int nv, int mode, int model, int dim, int steps, adjust_data* am)
+majorization(graph_t *mg, graph_t * g, int nv, int mode, int model, int dim, adjust_data* am)
 {
     double **coords;
     int ne;
-    int i, rv = 0;
+    int rv = 0;
     node_t *v;
     vtx_data *gp;
     node_t** nodes;
@@ -1136,7 +1131,7 @@ majorization(graph_t *mg, graph_t * g, int nv, int mode, int model, int dim, int
     expand_t margin;
 #endif
 #endif
-    int init = checkStart(g, nv, (mode == MODE_HIER ? INIT_SELF : INIT_RANDOM));
+    int init = checkStart(g, nv, mode == MODE_HIER ? INIT_SELF : INIT_RANDOM);
     int opts = checkExp (g);
 
     if (init == INIT_SELF)
@@ -1144,16 +1139,15 @@ majorization(graph_t *mg, graph_t * g, int nv, int mode, int model, int dim, int
 
     coords = N_GNEW(dim, double *);
     coords[0] = N_GNEW(nv * dim, double);
-    for (i = 1; i < Ndim; i++) {
+    for (int i = 1; i < Ndim; i++) {
 	coords[i] = coords[0] + i * nv;
     }
     if (Verbose) {
 	fprintf(stderr, "model %d smart_init %d stresswt %d iterations %d tol %f\n",
-		model, (init == INIT_SELF), opts & opt_exp_flag, MaxIter, Epsilon);
+		model, init == INIT_SELF, opts & opt_exp_flag, MaxIter, Epsilon);
 	fprintf(stderr, "convert graph: ");
 	start_timer();
         fprintf(stderr, "majorization\n");
-//     fprintf(stderr, "%i\n", count_nodes(g));
     }
     gp = makeGraphData(g, nv, &ne, mode, model, &nodes);
 
@@ -1173,7 +1167,7 @@ majorization(graph_t *mg, graph_t * g, int nv, int mode, int model, int dim, int
             char* str;
             ipsep_options opt;
             pointf* nsize;
-	    cluster_data *cs = (cluster_data*)cluster_map(mg,g);
+	    cluster_data *cs = cluster_map(mg,g);
 	    nsize = N_GNEW(nv, pointf);
             opt.edge_gap = lgap;
 #ifdef MOSEK
@@ -1219,15 +1213,18 @@ majorization(graph_t *mg, graph_t * g, int nv, int mode, int model, int dim, int
             else opt.gap.x = opt.gap.y = 2.0*PS2INCH(DFLT_MARGIN);
 	    if(Verbose)
 		fprintf(stderr,"gap=%f,%f\n",opt.gap.x,opt.gap.y);
-            for (i=0, v = agfstnode(g); v; v = agnxtnode(g, v),i++) {
-                nsize[i].x = ND_width(v);
-                nsize[i].y = ND_height(v);
+            {
+                size_t i = 0;
+                for (v = agfstnode(g); v; v = agnxtnode(g, v),i++) {
+                    nsize[i].x = ND_width(v);
+                    nsize[i].y = ND_height(v);
+                }
             }
 
 #ifdef DEBUG_COLA
 	    fprintf (stderr, "nv %d ne %d Ndim %d model %d MaxIter %d\n", nv, ne, Ndim, model, MaxIter);
 	    fprintf (stderr, "Nodes:\n");
-	    for (i = 0; i < nv; i++) {
+	    for (int i = 0; i < nv; i++) {
 		fprintf (stderr, "  %s (%f,%f)\n", nodes[i]->name, coords[0][i],  coords[1][i]);
 	    }
 	    fprintf (stderr, "\n");
@@ -1250,8 +1247,7 @@ majorization(graph_t *mg, graph_t * g, int nv, int mode, int model, int dim, int
     }
     else for (v = agfstnode(g); v; v = agnxtnode(g, v)) { /* store positions back in nodes */
 	int idx = ND_id(v);
-	int i;
-	for (i = 0; i < Ndim; i++) {
+	for (int i = 0; i < Ndim; i++) {
 	    ND_pos(v)[i] = coords[i][idx];
 	}
     }
@@ -1283,7 +1279,7 @@ static void subset_model(Agraph_t * G, int nG)
  * Assume the matrix already contains shortest path values.
  * Use the actual lengths provided the input for edges.
  */
-static void mds_model(graph_t * g, int nG)
+static void mds_model(graph_t * g)
 {
     long i, j;
     node_t *v;
@@ -1321,7 +1317,7 @@ static void kkNeato(Agraph_t * g, int nG, int model)
 	}
     } else if (model == MODEL_MDS) {
 	shortest_path(g, nG);
-	mds_model(g, nG);
+	mds_model(g);
     } else
 	shortest_path(g, nG);
     initial_positions(g, nG);
@@ -1348,16 +1344,20 @@ neatoLayout(Agraph_t * mg, Agraph_t * g, int layoutMode, int layoutModel,
 	MaxIter = atoi(str);
     else if (layoutMode == MODE_MAJOR)
 	MaxIter = DFLT_ITERATIONS;
+    else if (layoutMode == MODE_SGD)
+	MaxIter = 30;
     else
 	MaxIter = 100 * agnnodes(g);
 
     nG = scan_graph_mode(g, layoutMode);
-    if ((nG < 2) || (MaxIter < 0))
+    if (nG < 2 || MaxIter < 0)
 	return;
-    if (layoutMode)
-	majorization(mg, g, nG, layoutMode, layoutModel, Ndim, MaxIter, am);
-    else
+    if (layoutMode == MODE_KK)
 	kkNeato(g, nG, layoutModel);
+    else if (layoutMode == MODE_SGD)
+	sgd(g, layoutModel);
+    else
+	majorization(mg, g, nG, layoutMode, layoutModel, Ndim, am);
 }
 
 /* addZ;
@@ -1369,9 +1369,9 @@ static void addZ (Agraph_t* g)
     node_t* n;
     char    buf[BUFSIZ];
 
-    if ((Ndim >= 3) && N_z) {
+    if (Ndim >= 3 && N_z) {
 	for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
-	    sprintf(buf, "%lf", POINTS_PER_INCH * (ND_pos(n)[2]));
+	    snprintf(buf, sizeof(buf), "%lf", POINTS_PER_INCH * ND_pos(n)[2]);
 	    agxset(n, N_z, buf);
 	}
     }
@@ -1438,7 +1438,7 @@ void neato_layout(Agraph_t * g)
 	    /* If the user has not indicated packing but we are
 	     * using the new neato, turn packing on.
 	     */
-	    if ((Pack < 0) && layoutMode)
+	    if (Pack < 0 && layoutMode)
 		Pack = CL_OFFSET;
 	    pinfo.mode = l_node;
 	} else if (Pack < 0)
@@ -1472,8 +1472,7 @@ void neato_layout(Agraph_t * g)
 		pinfo.fixed = bp;
 		pinfo.doSplines = 1;
 		packGraphs(n_cc, cc, g, &pinfo);
-		if (bp)
-		    free(bp);
+		free(bp);
 	    }
 	    else {
 		neatoLayout(g, g, layoutMode, model, &am);
