@@ -164,7 +164,7 @@ late_smooth (graph_t* g, Agsym_t* sym, int dflt)
     if (!sym) return dflt;
     s = agxget (g, sym);
     if (isdigit(*s)) {
-#if (HAVE_GTS || HAVE_TRIANGLE)
+#if (defined(HAVE_GTS) || defined(HAVE_TRIANGLE))
 	if ((v = atoi (s)) <= SMOOTHING_RNG)
 #else
 	if ((v = atoi (s)) <= SMOOTHING_SPRING)
@@ -182,13 +182,13 @@ late_smooth (graph_t* g, Agsym_t* sym, int dflt)
 	    rv = SMOOTHING_NONE;
 	else if (!strcasecmp(s, "power_dist"))
 	    rv = SMOOTHING_STRESS_MAJORIZATION_POWER_DIST;
-#if (HAVE_GTS || HAVE_TRIANGLE)
+#if (defined(HAVE_GTS) || defined(HAVE_TRIANGLE))
 	else if (!strcasecmp(s, "rng"))
 	    rv = SMOOTHING_RNG;
 #endif
 	else if (!strcasecmp(s, "spring"))
 	    rv = SMOOTHING_SPRING;
-#if (HAVE_GTS || HAVE_TRIANGLE)
+#if (defined(HAVE_GTS) || defined(HAVE_TRIANGLE))
 	else if (!strcasecmp(s, "triangle"))
 	    rv = SMOOTHING_TRIANGLE;
 #endif
@@ -285,7 +285,7 @@ void sfdp_layout(graph_t * g)
 	spring_electrical_control ctrl = spring_electrical_control_new();
 
 	tuneControl (g, ctrl);
-#if (HAVE_GTS || HAVE_TRIANGLE)
+#if (defined(HAVE_GTS) || defined(HAVE_TRIANGLE))
 	graphAdjustMode(g, &am, "prism0");
 #else
 	graphAdjustMode(g, &am, 0);
