@@ -1895,7 +1895,9 @@ SparseMatrix SparseMatrix_copy(SparseMatrix A){
   if (!A) return A;
   B = SparseMatrix_general_new(A->m, A->n, A->nz, A->type, A->size, A->format);
   memcpy(B->ia, A->ia, sizeof(int)*((size_t)(A->m+1)));
-  memcpy(B->ja, A->ja, sizeof(int)*((size_t)(A->ia[A->m])));
+  if (A->ia[A->m] != 0) {
+    memcpy(B->ja, A->ja, sizeof(int)*((size_t)(A->ia[A->m])));
+  }
   if (A->a) memcpy(B->a, A->a, A->size*((size_t)A->nz));
   B->property = A->property;
   B->nz = A->nz;
@@ -2017,15 +2019,15 @@ typedef struct nodedata_struct* nodedata;
 static int cmp(void*i, void*j){
   nodedata d1, d2;
 
-  d1 = (nodedata) i;
-  d2 = (nodedata) j;
+  d1 = i;
+  d2 = j;
   if (d1->dist > d2->dist){
     return 1;
-  } else if (d1->dist == d2->dist){
-    return 0;
-  } else {
+  }
+  if (d1->dist < d2->dist) {
     return -1;
   }
+  return 0;
 }
 
 static int Dijkstra_internal(SparseMatrix A, int root, real *dist, int *nlist, int *list, real *dist_max, int *mask){
