@@ -8,14 +8,13 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#ifndef COLORUTIL_H
-#define COLORUTIL_H
+#pragma once
 
 #include <color.h>
 
 extern int colorxlate(char *str, gvcolor_t * color, color_type_t target_type);
 
-void rgb2hex(float r, float g, float b, char *cstring, char* opacity);/* dimension of cstring must be >=7 */
-char* hue2rgb(real hue, char *color);
+void rgb2hex(float r, float g, float b, char *cstring, const char* opacity);
+  /* dimension of cstring must be >=7 */
 
-#endif
+char* hue2rgb(real hue, char *color);
