@@ -8,6 +8,8 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
+#include <stdbool.h>
+#include <stddef.h>
 #include <sparse/general.h>
 #include <errno.h>
 
@@ -96,9 +98,8 @@ void vector_float_take(int n, float *v, int m, int *p, float **u){
 }
 
 static int comp_ascend(const void *s1, const void *s2){
-  const real *ss1, *ss2;
-  ss1 = (const real*) s1;
-  ss2 = (const real*) s2;
+  const real *ss1 = s1;
+  const real *ss2 = s2;
 
   if ((ss1)[0] > (ss2)[0]){
     return 1;
@@ -109,9 +110,8 @@ static int comp_ascend(const void *s1, const void *s2){
 }
 
 static int comp_ascend_int(const void *s1, const void *s2){
-  const int *ss1, *ss2;
-  ss1 = (const int*) s1;
-  ss2 = (const int*) s2;
+  const int *ss1 = s1;
+  const int *ss2 = s2;
 
   if ((ss1)[0] > (ss2)[0]){
     return 1;
@@ -173,14 +173,17 @@ real point_distance(real *p1, real *p2, int dim){
 }
 
 char *strip_dir(char *s){
-  int i, first = TRUE;
+  bool first = true;
   if (!s) return s;
-  for (i = strlen(s); i >= 0; i--) {
+  for (size_t i = strlen(s); ; i--) {
     if (first && s[i] == '.') {/* get rid of .mtx */
       s[i] = '\0';
-      first = FALSE;
+      first = false;
+    }
+    if (s[i] == '/') return &s[i+1];
+    if (i == 0) {
+      break;
     }
-    if (s[i] == '/') return (char*) &(s[i+1]);
   }
   return s;
 }
