@@ -8,8 +8,7 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
-#ifndef GENERAL_H
-#define GENERAL_H
+#pragma once
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -35,6 +34,7 @@
 #define clear_flag(a, flag) ((a) &=(~(flag)))
 
 #ifdef STANDALONE
+#define CALLOC calloc
 #define MALLOC malloc
 #define REALLOC realloc
 
@@ -61,6 +61,7 @@ typedef unsigned int boolean;
 extern unsigned char Verbose;
 
 #else  /* STANDALONE */
+#define CALLOC gcalloc
 #define MALLOC gmalloc
 #define REALLOC grealloc
 #endif    /* STANDALONE */
@@ -119,8 +120,3 @@ real point_distance(real *p1, real *p2, int dim);
 char *strip_dir(char *s);
 
 void scale_to_box(real xmin, real ymin, real xmax, real ymax, int n, int dim, real *x);
-
-#endif
-
-
-
