@@ -1,3 +1,10 @@
+"""
+Graphviz regression tests
+
+The test cases in this file relate to previously observed bugs. A failure of one
+of these indicates that a past bug has been reintroduced.
+"""
+
 import json
 import os
 from pathlib import Path
@@ -35,18 +42,22 @@ def is_ndebug_defined() -> bool:
 # saying "== Failed ==" which thus is not counted as a failure at the
 # end.
 
-# First run a subset of all the tests that produces equal output files
-# for all platforms and fail the test if there are differences.
-
 def test_regression_subset_differences():
+  """
+  First run a subset of all the tests that produces equal output files
+  for all platforms and fail the test if there are differences.
+  """
+
   os.chdir(Path(__file__).resolve().parent)
   subprocess.check_call([sys.executable, "rtest.py", "tests_subset.txt"])
 
-# Secondly, run all tests but ignore differences and fail the test
-# only if there is a crash. This will leave the differences for png
-# output in rtest/nhtml/index.html for review.
-
 def test_regression_failure():
+  """
+  Secondly, run all tests but ignore differences and fail the test
+  only if there is a crash. This will leave the differences for png
+  output in rtest/nhtml/index.html for review.
+  """
+
   os.chdir(Path(__file__).resolve().parent)
   result = subprocess.Popen([sys.executable, "rtest.py"],
                             stderr=subprocess.PIPE, universal_newlines=True)
@@ -333,6 +344,33 @@ def test_1221():
   # process this with dot
   subprocess.check_call(["dot", "-Tsvg", "-o", os.devnull, input])
 
+@pytest.mark.skipif(shutil.which("gv2gml") is None,
+                    reason="gv2gml not available")
+def test_1276():
+  """
+  quotes within a label should be escaped in translation to GML
+  https://gitlab.com/graphviz/graphviz/-/issues/1276
+  """
+
+  # DOT input containing a label with quotes
+  dot = 'digraph test {\n' \
+        '  x[label=<"Label">];\n' \
+        '}'
+
+  # process this to GML
+  p = subprocess.Popen(["gv2gml"], stdin=subprocess.PIPE,
+                       stdout=subprocess.PIPE, universal_newlines=True)
+  gml, _ = p.communicate(dot)
+
+  assert p.returncode == 0, "gv2gml failed"
+
+  # the unescaped label should not appear in the output
+  assert '""Label""' not in gml, "quotes not escaped in label"
+
+  # the escaped label should appear in the output
+  assert '"&quot;Label&quot;"' in gml or '"&#34;Label&#34;"' in gml, \
+    "escaped label not found in GML output"
+
 def test_1314():
   """
   test that a large font size that produces an overflow in Pango is rejected
@@ -541,7 +579,7 @@ def test_1767():
   dot = (Path(__file__).parent / "1767.dot").resolve()
   assert dot.exists(), "missing test case"
 
-  ret, stdout, _ = run_c(c_src, [dot], link=["cgraph", "gvc"])
+  ret, _, _ = run_c(c_src, [dot], link=["cgraph", "gvc"])
   assert ret == 0
 
   # FIXME: uncomment this when #1767 is fixed
@@ -781,6 +819,9 @@ for (prefix, _, files) in os.walk(ROOT):
 @pytest.mark.parametrize("src", html)
 @pytest.mark.skipif(shutil.which("xmllint") is None, reason="xmllint not found")
 def test_html(src: Path):
+  """
+  check that HTML files are valid and conforming
+  """
 
   # validate the file
   p = subprocess.Popen(["xmllint", "--nonet", "--noout", "--html", "--valid",
@@ -1005,6 +1046,36 @@ def test_1931():
   assert "line 3\nline 4" in xdot
   assert "line 5\nline 6" in xdot
 
+@pytest.mark.skipif(shutil.which("edgepaint") is None,
+                    reason="edgepaint not available")
+def test_1971():
+  """
+  edgepaint should reject invalid command line options
+  https://gitlab.com/graphviz/graphviz/-/issues/1971
+  """
+
+  # a basic graph that edgepaint can process
+  input =                                                                      \
+    'digraph {\n'                                                              \
+    '  graph [bb="0,0,54,108"];\n'                                             \
+    '  node [label="\\N"];\n'                                                  \
+    '  a       [height=0.5,\n'                                                 \
+    '           pos="27,90",\n'                                                \
+    '           width=0.75];\n'                                                \
+    '  b       [height=0.5,\n'                                                 \
+    '           pos="27,18",\n'                                                \
+    '           width=0.75];\n'                                                \
+    '  a -> b  [pos="e,27,36.104 27,71.697 27,63.983 27,54.712 27,46.112"];\n' \
+    '}'
+
+  # run edgepaint with an invalid option, `-rabbit`, that happens to have the
+  # same first character as valid options
+  args = ["edgepaint", "-rabbit"]
+  p = subprocess.Popen(args, stdin=subprocess.PIPE, universal_newlines=True)
+  p.communicate(input)
+
+  assert p.returncode != 0, "edgepaint incorrectly accepted '-rabbit'"
+
 @pytest.mark.xfail(strict=not is_ndebug_defined()) # FIXME
 def test_1990():
   """
@@ -1038,7 +1109,6 @@ def test_2057():
   ret, _, _ = run_c(c_src, link=["gvc"])
   assert ret == 0
 
-@pytest.mark.xfail(strict=True)
 def test_2078():
   """
   Incorrectly using the "layout" attribute on a subgraph should result in a
@@ -1060,9 +1130,27 @@ def test_2078():
 
   assert p.returncode != 0, "layout on subgraph was incorrectly accepted"
 
-  assert "layout" in stderr.lower(), "layout not mentioned in error message"
+  assert "layout attribute is invalid except on the root graph" in stderr, \
+    "expected warning not found"
 
-  assert "subgraph" in stderr.lower(), "subgraph not mentioned in error message"
+  # a graph that correctly uses layout
+  input = "graph {\n"          \
+          "  layout=osage\n" \
+          "  subgraph {\n"     \
+          "  }\n"              \
+          "}"
+
+  # ensure this one does not trigger warnings
+  p = subprocess.Popen(["dot", "-Tcanon", "-o", os.devnull],
+    stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE,
+    universal_newlines=True)
+  stdout, stderr = p.communicate(input)
+
+  assert p.returncode == 0, "correct layout use was rejected"
+
+  assert stdout.strip() == "", "unexpected output"
+  assert "layout attribute is invalid except on the root graph" not in stderr, \
+    "incorrect warning output"
 
 def test_2082():
   """
@@ -1125,6 +1213,79 @@ def test_2089_2():
   sys.stderr.write(stderr)
   assert ret == 0
 
+@pytest.mark.skipif(os.environ.get("build_system") == "msbuild" and
+                    os.environ.get("configuration") == "Debug",
+                    reason="Graphviz built with MSBuild in Debug mode has an "
+                           "insufficient stack size for this test")
+def test_2095():
+  """
+  Exceeding 1000 boxes during computation should not cause a crash
+  https://gitlab.com/graphviz/graphviz/-/issues/2095
+  """
+
+  # locate our associated test case in this directory
+  input = Path(__file__).parent / "2095.dot"
+  assert input.exists(), "unexpectedly missing test case"
+
+  # ask Graphviz to process it
+  subprocess.check_call(["dot", "-Tpdf", "-o", os.devnull, input])
+
+@pytest.mark.skipif(shutil.which("gv2gml") is None,
+                    reason="gv2gml not available")
+def test_2131():
+  """
+  gv2gml should be able to process basic Graphviz input
+  https://gitlab.com/graphviz/graphviz/-/issues/2131
+  """
+
+  # a trivial graph
+  input = "digraph { a -> b; }"
+
+  # ask gv2gml what it thinks of this
+  p = subprocess.Popen(["gv2gml"], stdin=subprocess.PIPE,
+                       universal_newlines=True)
+  p.communicate(input)
+
+  assert p.returncode == 0, "gv2gml rejected a basic graph"
+
+@pytest.mark.skipif(shutil.which("gvpr") is None,
+                    reason="gvpr not available")
+@pytest.mark.parametrize("examine", ("indices", "tokens"))
+def test_2138(examine: str):
+  """
+  gvpr splitting and tokenizing should not result in trailing garbage
+  https://gitlab.com/graphviz/graphviz/-/issues/2138
+  """
+
+  # find our co-located GVPR program
+  script = (Path(__file__).parent / "2138.gvpr").resolve()
+  assert script.exists(), "missing test case"
+
+  # run it with NUL input
+  out = subprocess.check_output(["gvpr", "-f", script],
+                                stdin=subprocess.DEVNULL)
+
+  # Decode into text. We do this instead of `universal_newlines=True` above
+  # because the trailing garbage can contain invalid UTF-8 data causing cryptic
+  # failures. We want to correctly surface this as trailing garbage, not an
+  # obscure UTF-8 decoding error.
+  result = out.decode("utf-8", "replace")
+
+  if examine == "indices":
+    # check no indices are miscalculated
+    index_re = r"^// index of space \(st\) :\s*(?P<index>-?\d+)\s*<< must " \
+               r"NOT be less than -1$"
+    for m in re.finditer(index_re, result, flags=re.MULTILINE):
+      index = int(m.group("index"))
+      assert index >= -1, "illegal index computed"
+
+  if examine == "tokens":
+    # check for text the author of 2138.gvpr expected to find
+    assert "// tok[3]    >>3456789<<   should NOT include trailing spaces or " \
+      "junk chars" in result, "token 3456789 not found or has trailing garbage"
+    assert "// tok[7]    >>012<<   should NOT include trailing spaces or "     \
+      "junk chars" in result, "token 012 not found or has trailing garbage"
+
 def test_package_version():
   """
   The graphviz_version.h header should define a non-empty PACKAGE_VERSION
@@ -1198,16 +1359,16 @@ def test_xdot_json():
 
 # find all .vcxproj files
 VCXPROJS: List[Path] = []
-for root, _, files in os.walk(ROOT):
+for repo_root, _, files in os.walk(ROOT):
   for stem in files:
     # skip files generated by MSBuild itself
     if stem in ("VCTargetsPath.vcxproj", "CompilerIdC.vcxproj",
                 "CompilerIdCXX.vcxproj"):
       continue
-    p = Path(root) / stem
-    if p.suffix != ".vcxproj":
+    full_path = Path(repo_root) / stem
+    if full_path.suffix != ".vcxproj":
       continue
-    VCXPROJS.append(p)
+    VCXPROJS.append(full_path)
 
 @pytest.mark.parametrize("vcxproj", VCXPROJS)
 def test_vcxproj_inclusive(vcxproj: Path):
